@@ -32,15 +32,27 @@ from opentelemetry.sdk import trace
 from opentelemetry.sdk.environment_variables import (
     OTEL_EXPORTER_JAEGER_CERTIFICATE,
     OTEL_EXPORTER_JAEGER_ENDPOINT,
+    OTEL_EXPORTER_JAEGER_TIMEOUT,
     OTEL_RESOURCE_ATTRIBUTES,
 )
 from opentelemetry.sdk.resources import SERVICE_NAME, Resource
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import SpanExportResult
 from opentelemetry.sdk.util.instrumentation import InstrumentationInfo
+from opentelemetry.test.spantestutil import (
+    get_span_with_dropped_attributes_events_links,
+)
 from opentelemetry.trace.status import Status, StatusCode
 
 
+def _translate_spans_with_dropped_attributes():
+    span = get_span_with_dropped_attributes_events_links()
+    translate = Translate([span])
+
+    # pylint: disable=protected-access
+    return translate._translate(pb_translator.ProtobufTranslator("svc"))
+
+
 # pylint:disable=no-member
 class TestJaegerExporter(unittest.TestCase):
     def setUp(self):
@@ -71,6 +83,7 @@ class TestJaegerExporter(unittest.TestCase):
                 OTEL_EXPORTER_JAEGER_CERTIFICATE: os.path.dirname(__file__)
                 + "/certs/cred.cert",
                 OTEL_RESOURCE_ATTRIBUTES: "service.name=my-opentelemetry-jaeger",
+                OTEL_EXPORTER_JAEGER_TIMEOUT: "5",
             },
         )
 
@@ -81,6 +94,7 @@ class TestJaegerExporter(unittest.TestCase):
         self.assertEqual(exporter.service_name, service)
         self.assertIsNotNone(exporter._collector_grpc_client)
         self.assertEqual(exporter.collector_endpoint, collector_endpoint)
+        self.assertEqual(exporter._timeout, 5)
         self.assertIsNotNone(exporter.credentials)
         env_patch.stop()
 
@@ -472,8 +486,23 @@ class TestJaegerExporter(unittest.TestCase):
         exporter.export([span])
         self.assertEqual(exporter.service_name, "test")
 
+    def test_dropped_span_attributes(self):
+        spans = _translate_spans_with_dropped_attributes()
+        tags_by_keys = {
+            tag.key: tag.v_str or tag.v_int64 for tag in spans[0].tags
+        }
+        self.assertEqual(1, tags_by_keys["otel.dropped_links_count"])
+        self.assertEqual(2, tags_by_keys["otel.dropped_attributes_count"])
+        self.assertEqual(3, tags_by_keys["otel.dropped_events_count"])
 
-class MockResponse:
-    def __init__(self, status_code):
-        self.status_code = status_code
-        self.text = status_code
+    def test_dropped_event_attributes(self):
+        spans = _translate_spans_with_dropped_attributes()
+        fields_by_keys = {
+            tag.key: tag.v_str or tag.v_int64
+            for tag in spans[0].logs[0].fields
+        }
+        # get events
+        self.assertEqual(
+            2,
+            fields_by_keys["otel.dropped_attributes_count"],
+        )
